
''' 

'Secret module' was created to ease operations on python lists.




'''



def __secret__(index_pos ,a = list,b = list):
    ''' this function collects list elements of 'b' and inserts them
        into a specified by 'index_pos' to list 'a' and then prints them '''
    a.insert(index_pos, b)
    print(a)


def __pack__(list_name = list):
    ''' this function collect elements of given list and sorts them by
        their value, example: [1,3,6,4] >>> [1,3,4,6] and then prints them '''
    list_name.sort()
    print(list_name)

def __odd__(list_name = list):
    ''' this function check every item in the list and prints whether it is an
        odd number(num) or a normal one '''
    for odd_ones in list_name:
        if odd_ones % 2 != 0:
            print(f'odd num: {odd_ones}')
        if odd_ones % 2 == 0:
            print(print(f'normal num:{odd_ones}'))
        


from setuptools import setup, find_packages


classifiers = [
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Education',
    'Operating System :: Microsoft :: Windows :: Windows 10',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3'
]

setup(
    name = 'secretListing',
    version = '0.0.1',
    description = 'Makes operations on lists easy.',
    long_description = open('README.txt').read() + '\n\n' + open('CHANGELOG.txt').read(),
    url = '',
    author = 'Damian Czapla',
    author_email = 'damianczapla121212@gmail.com',
    License = 'MIT',
    classifiers = classifiers,
    keywords = 'secret',
    packages = find_packages(),
    install_requires = ['']

)